/// <reference types="lodash" />
import { ICompletionResponse } from './ICompletionResponse';
/**
 * Responsible for fetching completions from a model and adding them to the input.
 */
export declare class SmartInputFetcher {
    addCompletion: (text: string, completion: ICompletionResponse) => void;
    modelId?: string | undefined;
    mockCompletion?: ((text: string) => string | null) | undefined;
    /**
     * sequenceId is used to ensure that we don't add completions from a previous fetch
     */
    sequenceId: number;
    sessionId: string;
    fetchCache: Record<string, ICompletionResponse | null>;
    alreadySeen: Set<string>;
    alreadyAccepted: Set<string>;
    /**
     * currentCompletion is used to track the latest text that was sent to the model for fetching completions, and the
     * completion that was returned (if any ~ we may be waiting for it).
     */
    currentCompletion: {
        sequenceId: number;
        text: string;
        completion?: string | null;
    } | null;
    constructor(addCompletion: (text: string, completion: ICompletionResponse) => void, modelId?: string | undefined, mockCompletion?: ((text: string) => string | null) | undefined);
    fetchCompletion: import("lodash").DebouncedFunc<(text: string, context: any) => Promise<ICompletionResponse | null>>;
    updateCompletion(completionSid: string, arg: {
        seen?: boolean;
        accepted?: boolean;
    }): void;
    sendEvents: import("lodash").DebouncedFunc<(text: string, context: any) => void>;
}
